default_registry

Function default_registry 

pub fn default_registry() -> ToolRegistry
Create a registry pre-loaded with all built-in Nanny tools.

Currently includes:

  • http_get — makes a single HTTP GET request

This is the standard starting point for most executions. Register additional tools on top of this if needed.